### Name: selfPacedReadingHeid
### Title: Self-paced reading latencies for Dutch neologisms
### Aliases: selfPacedReadingHeid
### Keywords: datasets

### ** Examples

data(selfPacedReadingHeid)

# data validation
plot(sort(selfPacedReadingHeid$RT))   
selfPacedReadingHeid = selfPacedReadingHeid[selfPacedReadingHeid$RT > 5 & 
  selfPacedReadingHeid$RT < 7.2,]

# fitting a mixed-effects model

library(lme4, keep.source = FALSE)
x = selfPacedReadingHeid[,12:15]
x.pr = prcomp(x, center = TRUE, scale = TRUE)
selfPacedReadingHeid$PC1 = x.pr$x[,1]

selfPacedReadingHeid.lmer = lmer(RT ~ RTtoPrime + LengthInLetters + 
  PC1 * Condition + (1|Subject) + (1|Word), 
  data = selfPacedReadingHeid)  
pvals.fnc(selfPacedReadingHeid.lmer)$summary

# model criticism

selfPacedReadingHeid.lmerA = lmer(RT ~ RTtoPrime + LengthInLetters + 
PC1 * Condition + (1|Subject) + (1|Word), data = 
selfPacedReadingHeid[abs(scale(resid(selfPacedReadingHeid.lmer))) < 2.5, ])

qqnorm(resid(selfPacedReadingHeid.lmerA))

pvals.fnc(selfPacedReadingHeid.lmerA)$summary



